//Importing the required modules from D3 and scatterplot
import { csv, select,legendColor } from 'd3';
import { scatterPlot } from './scatterPlot';

// reading the gist data URl into the constant variable
const csvUrl = 'https://gist.githubusercontent.com/Saneem21/1662b651f3b7a8277b5a56ec773bb4f2/raw/2625ae723ee6508eec83ab2a46499918132f5dbe/iris.csv'

//Defining the function parsRow with the input parameters d 
const parseRow = (d) => {
  d.sepal_length = +d.sepal_length;
  d.sepal_width = +d.sepal_width;
  d.petal_length = +d.petal_length;
  d.petal_width = +d.petal_width;
  return d;
};
//creating an SVG object and add it to the HTML body. setting the width and height of the SVG object to the width and height window
const width = window.innerWidth;
const height = window.innerHeight;
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

//defining the variables 
const xValue = (d) => d.petal_length;
const yValue = (d) => d.petal_width;
const rxValue = (d) => d.sepal_length;
const ryValue = (d) => d.sepal_width;
const speciesValue = (d) => d.species;
const colorValue = d => d.species;
const colorLabel = 'Species';

// The main funcation These lines load the Iris dataset, apply the parseRow function to each row, and transform each data point into a mark object with x, y, species, rx, and ry properties.
const main = async () => {
// loading data from the CSV file using D3's csv method and parsing each row using parseRow function
  const data = await csv(csvUrl, parseRow);
  const x = xValue((d) => d.petal_width);
  const y = yValue((d) => d.sepal_length);
  const marker = (d) => {
        	switch(d){
              
            default:
              return 'blue';
          }
        }
  // creating an array of objects containing the values for each data point
  const marks = data.map((d) => ({
          x: xValue((d) => d.petal_width),
          y: yValue((d) => d.sepal_length),
          species: speciesValue(d),
          color: marker(speciesValue(d)),
        	rx: rxValue(d),
          ry: ryValue(d),
                      
        }));
  // scatter plot creation object with various properties, such as width, height, margin, and symbol value.
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d.petal_width)
    .yValue((d) => d.sepal_length)
    .symbolValue((d) => d.species)
    .margin({
      top: 20,
      right: 20,
      bottom: 40,
      left: 50,
    })
    .size(80);
  

  const g = svg.append('g')
          .attr('transform', `translate(${100},${100})`);

      const colorLegendG = g.append('g')
          .attr('transform', `translate(${100}, 150)`);
svg
          
          .data(marks)
          .attr('cx', (d) => d.x)
          .attr('cy', (d) => d.y)
        	.attr('fill', (d) => d.color)
        	.attr('rx', (d) => (d.rx))
        	.attr('ry', (d) => (d.ry));


  const columns = [
    'petal_width',
    'sepal_width',
    'petal_length',
    'sepal_length',
  ];
  //loop call the function in loop for every 2 sec
  let i = 0;
  setInterval(() => {
    plot.xValue((d) => d[columns[i % columns.length]]);
    svg.selectAll('text').remove();
    svg.call(plot);
    
    i++;
  }, 2000);
};
main();
